[hive] branch master updated: HIVE-25997: Fix release source packaging (Zoltan Haindrich and Peter Vary, reviewed by Stamatis Zampetakis) (#3067)

2022-03-03 Thread pvary
This is an automated email from the ASF dual-hosted git repository.

pvary pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/hive.git


The following commit(s) were added to refs/heads/master by this push:
 new 95c6155  HIVE-25997: Fix release source packaging (Zoltan Haindrich 
and Peter Vary, reviewed by Stamatis Zampetakis) (#3067)
95c6155 is described below

commit 95c6155677b5a288b6bc571b11caf2c8eb80825f
Author: pvary 
AuthorDate: Thu Mar 3 15:48:43 2022 +0100

HIVE-25997: Fix release source packaging (Zoltan Haindrich and Peter Vary, 
reviewed by Stamatis Zampetakis) (#3067)
---
 Jenkinsfile |  7 +++
 packaging/src/main/assembly/src.xml | 14 ++
 2 files changed, 21 insertions(+)

diff --git a/Jenkinsfile b/Jenkinsfile
index b079d51..70d5b91 100644
--- a/Jenkinsfile
+++ b/Jenkinsfile
@@ -304,6 +304,13 @@ dev-support/nightly
 '''
 buildHive("install -Dtest=noMatches -Pdist -pl packaging -am")
 }
+stage('Verify') {
+sh '''#!/bin/bash
+set -e
+tar -xzf packaging/target/apache-hive-*-nightly-*-src.tar.gz
+'''
+buildHive("install -Dtest=noMatches -Pdist,iceberg -f 
apache-hive-*-nightly-*/pom.xml")
+}
   }
   }
   for (int i = 0; i < splits.size(); i++) {
diff --git a/packaging/src/main/assembly/src.xml 
b/packaging/src/main/assembly/src.xml
index 625fcf2..8fc5bdc 100644
--- a/packaging/src/main/assembly/src.xml
+++ b/packaging/src/main/assembly/src.xml
@@ -100,12 +100,26 @@
 storage-api/**/*
 standalone-metastore/metastore-common/**/*
 standalone-metastore/metastore-server/**/*
+standalone-metastore/metastore-tools/**/*
+standalone-metastore/src/assembly/src.xml
+standalone-metastore/pom.xml
 streaming/**/*
 testutils/**/*
 upgrade-acid/**/*
 vector-code-gen/**/*
 kryo-registrator/**/*
 kudu-handler/**/*
+parser/**/*
+udf/**/*
+iceberg/iceberg-catalog/**/*
+iceberg/iceberg-handler/**/*
+iceberg/iceberg-shading/**/*
+iceberg/patched-iceberg-api/**/*
+iceberg/patched-iceberg-core/**/*
+iceberg/patched-iceberg-data/**/*
+iceberg/patched-iceberg-orc/**/*
+iceberg/checkstyle/**/*
+iceberg/pom.xml
   
   /
 


[hive] branch master updated: HIVE-24390: Spelling common (#2810) (Josh Soref reviewed by Zoltan Haindrich)

2022-03-03 Thread kgyrtkirk
This is an automated email from the ASF dual-hosted git repository.

kgyrtkirk pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/hive.git


The following commit(s) were added to refs/heads/master by this push:
 new adea623  HIVE-24390: Spelling common (#2810) (Josh Soref reviewed by 
Zoltan Haindrich)
adea623 is described below

commit adea623294fd0a1a1502abc441794a61739cf8dc
Author: Josh Soref <2119212+jso...@users.noreply.github.com>
AuthorDate: Thu Mar 3 07:33:33 2022 -0500

HIVE-24390: Spelling common (#2810) (Josh Soref reviewed by Zoltan 
Haindrich)
---
 common/pom.xml |  2 +-
 .../hadoop/hive/common/CompressionUtils.java   | 10 +++---
 .../org/apache/hadoop/hive/common/JvmMetrics.java  |  2 +-
 .../apache/hadoop/hive/common/JvmPauseMonitor.java |  2 +-
 .../org/apache/hadoop/hive/common/LogUtils.java|  2 +-
 .../apache/hadoop/hive/common/jsonexplain/Op.java  | 12 +++
 .../hadoop/hive/common/jsonexplain/Stage.java  | 34 +-
 .../hadoop/hive/common/jsonexplain/Vertex.java |  8 ++---
 .../apache/hadoop/hive/common/type/Decimal128.java |  6 ++--
 .../apache/hadoop/hive/common/type/HiveChar.java   |  2 +-
 .../hadoop/hive/common/type/SqlMathUtil.java   |  2 +-
 .../java/org/apache/hadoop/hive/conf/HiveConf.java | 42 +++---
 .../java/org/apache/hadoop/hive/ql/ErrorMsg.java   | 14 
 .../apache/hive/common/util/HiveStringUtils.java   | 10 +++---
 .../java/org/apache/hive/http/JMXJsonServlet.java  |  2 +-
 .../hive/http/Log4j2ConfiguratorServlet.java   | 10 +++---
 .../java/org/apache/hive/http/ProfileServlet.java  |  2 +-
 .../hadoop/hive/common/jsonexplain/TestStage.java  | 42 +++---
 .../hadoop/hive/common/jsonexplain/TestVertex.java |  2 +-
 .../hadoop/hive/common/type/TestDecimal128.java| 16 -
 .../hadoop/hive/conf/TestHiveConfRestrictList.java |  2 +-
 .../hive/common/util/TestHiveStringUtils.java  |  2 +-
 .../clientnegative/stats_aggregator_error_2.q.out  | 10 +++---
 .../clientnegative/stats_publisher_error_1.q.out   |  8 ++---
 .../clientnegative/stats_publisher_error_2.q.out   | 10 +++---
 .../llap/stats_aggregator_error_1.q.out|  2 +-
 .../llap/stats_publisher_error_1.q.out |  2 +-
 .../hadoop/hive/common/metrics/common/Metrics.java |  4 +--
 .../metrics/metrics2/JsonFileMetricsReporter.java  |  2 +-
 29 files changed, 132 insertions(+), 132 deletions(-)

diff --git a/common/pom.xml b/common/pom.xml
index 912de29..f89f273 100644
--- a/common/pom.xml
+++ b/common/pom.xml
@@ -28,7 +28,7 @@
   
   
 
-
+
 
   org.apache.hive
   hive-classification
diff --git a/common/src/java/org/apache/hadoop/hive/common/JvmMetrics.java 
b/common/src/java/org/apache/hadoop/hive/common/JvmMetrics.java
index b758abe..6edf396 100644
--- a/common/src/java/org/apache/hadoop/hive/common/JvmMetrics.java
+++ b/common/src/java/org/apache/hadoop/hive/common/JvmMetrics.java
@@ -128,7 +128,7 @@ public class JvmMetrics implements MetricsSource {
 
 if (pauseMonitor != null) {
   rb.addCounter(GcNumWarnThresholdExceeded,
-
diff --git 
a/common/src/java/org/apache/hadoop/hive/common/CompressionUtils.java 
b/common/src/java/org/apache/hadoop/hive/common/CompressionUtils.java
index a2e90e1..c5c050b 100644
--- a/common/src/java/org/apache/hadoop/hive/common/CompressionUtils.java
+++ b/common/src/java/org/apache/hadoop/hive/common/CompressionUtils.java
@@ -117,7 +117,7 @@ public class CompressionUtils {
* @throws IOException
* @throws FileNotFoundException
*
    * @return The {@link List} of {@link File}s with the untared content.
* @throws ArchiveException
*/
   public static List unTar(final String inputFileName, final String 
outputDirName)
@@ -136,7 +136,7 @@ public class CompressionUtils {
* @throws IOException
* @throws FileNotFoundException
*
    * @return The {@link List} of {@link File}s with the untared content.
* @throws ArchiveException
*/
   public static List unTar(final String inputFileName, final String 
outputDirName,
@@ -145,7 +145,7 @@ public class CompressionUtils {
 File inputFile = new File(inputFileName);
 File outputDir = new File(outputDirName);
 
-final List untaredFiles = new LinkedList();
+final List untarredFiles = new LinkedList();
 InputStream is = null;
 
 try {
@@ -200,10 +200,10 @@ public class CompressionUtils {
   IOUtils.copy(debInputStream, outputFileStream);
   outputFileStream.close();
 }
-untaredFiles.add(outputFile);
+untarredFiles.add(outputFile);
   }
   debInputStream.close();
-  return untaredFiles;
+  return untarredFiles;
 
 } finally {
   if (is != null)  is.close();
@@ -117,7 +117,7 @@ public class CompressionUtils {
* @throws FileNotFoundException
*
-   * @return The {@link List} of {@link File}s with the untared content.
+   * @return The {@link List} of {@link File}s with the untarred content.
* @throws ArchiveException
*/
@@ -136,7 +136,7 @@ public class CompressionUtils {
* @throws FileNotFoundException
*
-   * @return The {@link List} of {@link File}s with the untared content.
+   * @return The {@link List} of {@link File}s with the untarred content.
* @throws ArchiveException
*/